@@ -19,6 +19,7 @@
 # MA 02110-1301, USA.
 
 package Lintian::shared_libs;
+
 use strict;
 use warnings;
 use autodie;
@@ -28,14 +29,21 @@ use List::MoreUtils qw(any none uniq);
 
 use Lintian::Data;
 use Lintian::Relation;
-use Lintian::Tags qw(tag);
 use Lintian::Util qw(internal_error strip);
 
+use Moo;
+use namespace::clean;
+
+with 'Lintian::Check';
+
 # Libraries that should only be used in the presence of certain capabilities
 # may be located in subdirectories of the standard ldconfig search path with
 # one of the following names.
 my $HWCAP_DIRS = Lintian::Data->new('shared-libs/hwcap-dirs');
 
+my $UNKNOWN_SHARED_LIBRARY_EXCEPTIONS
+  = Lintian::Data->new('shared-libs/unknown-shared-library-exceptions');
+
 # List of symbols file meta-fields.
 my %symbols_meta_fields = map { $_ => 1 }qw(
   Build-Depends-Package
@@ -45,14 +53,19 @@ my %symbols_meta_fields = map { $_ => 1 }qw(
 my $ldconfig_dirs = Lintian::Data->new('shared-libs/ldconfig-dirs');
 my $MA_DIRS = Lintian::Data->new('common/multiarch-dirs', qr/\s++/);
 
-sub run {
-    my ($pkg, $type, $info, $proc, $group) = @_;
+sub always {
+    my ($self) = @_;
 
-    my ($must_call_ldconfig, %SONAME, %sharedobject);
+    my $pkg = $self->package;
+    my $type = $self->type;
+    my $processable = $self->processable;
+    my $group = $self->group;
+
+    my ($must_call_ldconfig, %SONAME, %SONAMES, %STATIC_LIBS, %sharedobject);
     my @shlibs;
     my @words;
     my @devpkgs;
-    my $objdump = $info->objdump_info;
+    my $objdump = $processable->objdump_info;
 
     # 1st step: get info about shared libraries installed by this package
     foreach my $file (sort keys %{$objdump}) {
@@ -60,7 +73,9 @@ sub run {
           if exists($objdump->{$file}{SONAME});
     }
 
-    foreach my $file ($info->sorted_index) {
+    foreach my $file ($processable->sorted_index) {
+        $SONAMES{$1} = 1 if $file =~ m,.*\/lib([^/]+)\.so$,;
+        $STATIC_LIBS{$1} = 1 if $file =~ m,.*\/lib([^/]+)\.a$,;
         next if not $file->is_file;
         my $fileinfo = $file->file_info;
         if (   $fileinfo =~ m/^[^,]*\bELF\b/
@@ -77,8 +92,8 @@ sub run {
 
     if (%SONAME) {
         foreach my $bin ($group->get_binary_processables) {
-            next unless $bin->pkg_name =~ m/\-dev$/;
-            if ($bin->info->relation('strong')->implies($pkg)) {
+            next unless $bin->name =~ m/\-dev$/;
+            if ($bin->relation('strong')->implies($pkg)) {
                 push @devpkgs, $bin;
             }
         }
@@ -86,7 +101,7 @@ sub run {
 
     # 2nd step: read package contents
 
-    for my $cur_file ($info->sorted_index) {
+    for my $cur_file ($processable->sorted_index) {
         # shared library?
 
         my $normalized_target;
@@ -122,7 +137,7 @@ sub run {
             # Now that we're sure this is really a shared library, report on
             # non-PIC problems.
             if ($objdump->{$cur_file}{TEXTREL}) {
-                tag 'shlib-with-non-pic-code', $cur_file;
+                $self->tag('shlib-with-non-pic-code', $cur_file);
             }
 
             my @symbol_names
@@ -132,7 +147,7 @@ sub run {
                 # If it has an INTERP section it might be an application with
                 # a SONAME (hi openjdk-6, see #614305).  Also see the comment
                 # for "shlib-with-executable-bit" below.
-                tag 'shlib-calls-exit', $cur_file
+                $self->tag('shlib-calls-exit', $cur_file)
                   unless $objdump->{$cur_file}{INTERP};
             }
 
@@ -143,25 +158,26 @@ sub run {
                 # designed to do something useful when executed, so don't
                 # report an error.  Also give ld.so a pass, since it's
                 # special.
-                tag 'shlib-with-executable-bit', $cur_file, $perms
+                $self->tag('shlib-with-executable-bit', $cur_file, $perms)
                   unless ($objdump->{$cur_file}{INTERP}
                     or $cur_file =~ m,^lib.*/ld-[\d.]+\.so$,);
             } elsif ($perm != 0644) {
-                tag 'shlib-with-bad-permissions', $cur_file, $perms;
+                $self->tag('shlib-with-bad-permissions', $cur_file, $perms);
             }
 
             # executable stack.
             if (not defined $objdump->{$cur_file}{'PH'}{STACK}) {
-                if (defined $info->field('architecture')) {
-                    my $arch = $info->field('architecture');
-                    tag 'shlib-without-PT_GNU_STACK-section', $cur_file;
+                if (defined $processable->field('architecture')) {
+                    my $arch = $processable->field('architecture');
+                    $self->tag('shlib-without-PT_GNU_STACK-section',$cur_file);
                 }
             } elsif ($objdump->{$cur_file}{'PH'}{STACK}{flags} ne 'rw-'){
-                tag 'shlib-with-executable-stack', $cur_file;
+                $self->tag('shlib-with-executable-stack', $cur_file);
             }
         } elsif ($ldconfig_dirs->known(dirname($cur_file))
             && exists $sharedobject{$cur_file}) {
-            tag 'sharedobject-in-library-directory-missing-soname', $cur_file;
+            $self->tag('sharedobject-in-library-directory-missing-soname',
+                $cur_file);
         } elsif ($cur_file =~ m/\.la$/ and not defined $cur_file->link) {
             local $_;
             my $fd = $cur_file->open;
@@ -181,11 +197,12 @@ sub run {
                       if ($value
                         =~ m,^/usr/lib/python[\d.]+/(?:site|dist)-packages,
                         and $expected =~ m,^/usr/share/pyshared,);
-                    tag 'incorrect-libdir-in-la-file', $cur_file,
-                      "$value != $expected"
+                    $self->tag('incorrect-libdir-in-la-file', $cur_file,
+                        "$value != $expected")
                       unless($expected eq $value);
                 } elsif ($field eq 'dependency_libs'){
-                    tag 'non-empty-dependency_libs-in-la-file', $cur_file;
+                    $self->tag('non-empty-dependency_libs-in-la-file',
+                        $cur_file);
                 }
             }
             close($fd);
@@ -195,7 +212,7 @@ sub run {
     # 3rd step: check if shlib symlinks are present and in correct order
     for my $shlib_file (keys %SONAME) {
         # file found?
-        if (not $info->index($shlib_file)) {
+        if (not $processable->index($shlib_file)) {
             internal_error(
                 "shlib $shlib_file not found in package (should not happen!)");
         }
@@ -207,31 +224,32 @@ sub run {
 
         # symlink found?
         my $link_file = "$dir/$SONAME{$shlib_file}";
-        if (not $info->index($link_file)) {
-            tag 'ldconfig-symlink-missing-for-shlib',
-              "$link_file $shlib_file $SONAME{$shlib_file}";
+        if (not $processable->index($link_file)) {
+            $self->tag('ldconfig-symlink-missing-for-shlib',
+                "$link_file $shlib_file $SONAME{$shlib_file}");
         } else {
             # $link_file really another file?
             if ($link_file eq $shlib_file) {
                 # the library file uses its SONAME, this is ok...
             } else {
                 # $link_file really a symlink?
-                if ($info->index($link_file)->is_symlink) {
+                if ($processable->index($link_file)->is_symlink) {
                     # yes.
 
                     # $link_file pointing to correct file?
-                    if ($info->index($link_file)->link eq $shlib_name) {
+                    if ($processable->index($link_file)->link eq $shlib_name) {
                         # ok.
                     } else {
-                        tag 'ldconfig-symlink-referencing-wrong-file',
-                          join(q{ },
-                            "$link_file ->",
-                            $info->index($link_file)->link,
-                            "instead of $shlib_name");
+                        $self->tag(
+                            'ldconfig-symlink-referencing-wrong-file',
+                            join(q{ },
+                                "$link_file ->",
+                                $processable->index($link_file)->link,
+                                "instead of $shlib_name"));
                     }
                 } else {
-                    tag 'ldconfig-symlink-is-not-a-symlink',
-                      "$shlib_file $link_file";
+                    $self->tag('ldconfig-symlink-is-not-a-symlink',
+                        "$shlib_file $link_file");
                 }
             }
         }
@@ -245,8 +263,9 @@ sub run {
         # if shlib doesn't _have_ a version, then $link_file and
         # $shlib_file will be equal, and it's not a development link,
         # so don't complain.
-        if ($info->index($link_file) and $link_file ne $shlib_file) {
-            tag 'non-dev-pkg-with-shlib-symlink', "$shlib_file $link_file";
+        if ($processable->index($link_file) and $link_file ne $shlib_file) {
+            $self->tag('non-dev-pkg-with-shlib-symlink',
+                "$shlib_file $link_file");
         } elsif (@devpkgs) {
             # -dev package - it needs a shlib symlink
             my $ok = 0;
@@ -258,7 +277,7 @@ sub run {
 
             push @alt, $link_file;
 
-            if ($proc->pkg_src =~ m/^gcc-(\d+(?:.\d+)?)$/o) {
+            if ($processable->source =~ m/^gcc-(\d+(?:.\d+)?)$/o) {
                 # gcc has a lot of bi-arch libs and puts the dev symlink
                 # in slightly different directories (to be co-installable
                 # with itself I guess).  Allegedly, clang (etc.) have to
@@ -266,7 +285,7 @@ sub run {
                 # acceptable...
                 my $gcc_ver = $1;
                 my $basename = basename($link_file);
-                my $madir = $MA_DIRS->value($proc->pkg_arch);
+                my $madir = $MA_DIRS->value($processable->architecture);
                 my @madirs;
                 if (defined $madir) {
                     # For i386-*, the triplet GCC uses can be i586-* or i686-*.
@@ -302,31 +321,33 @@ sub run {
 
           PKG:
             foreach my $devpkg (@devpkgs) {
-                my $dinfo = $devpkg->info;
+
                 foreach my $link (@alt) {
-                    if ($dinfo->index($link)) {
+                    if ($devpkg->index($link)) {
                         $ok = 1;
                         last PKG;
                     }
                 }
             }
-            tag 'dev-pkg-without-shlib-symlink', "$shlib_file $link_file"
+            $self->tag('dev-pkg-without-shlib-symlink',
+                "$shlib_file $link_file")
               unless $ok;
         }
     }
 
     # 4th step: check shlibs control file
     # $version may be undef in very broken packages
-    my $version = $info->field('version');
+    my $version = $processable->field('version');
     my $provides = $pkg;
     $provides .= "( = $version)" if defined $version;
     # Assume the version to be a non-native version to avoid
     # uninitialization warnings later.
     $version = '0-1' unless defined $version;
-    $provides = Lintian::Relation->and($info->relation('provides'), $provides);
+    $provides
+      = Lintian::Relation->and($processable->relation('provides'), $provides);
 
-    my $shlibsf = $info->control_index('shlibs');
-    my $symbolsf = $info->control_index('symbols');
+    my $shlibsf = $processable->control_index('shlibs');
+    my $symbolsf = $processable->control_index('symbols');
     my (%shlibs_control, %symbols_control);
 
     # control files are not symlinks (or other "weird" things).
@@ -343,7 +364,7 @@ sub run {
         my $soname = format_soname($SONAME{$_});
         if ($soname !~ / /) {
             $unversioned_shlibs{$_} = 1;
-            tag 'shlib-without-versioned-soname', $_, $soname
+            $self->tag('shlib-without-versioned-soname', $_, $soname)
               if $ldconfig_dirs->known(dirname($_));
         }
     }
@@ -353,7 +374,8 @@ sub run {
         # no shared libraries included in package, thus shlibs control
         # file should not be present
         if ($shlibsf) {
-            tag 'pkg-has-shlibs-control-file-but-no-actual-shared-libs';
+            $self->tag(
+                'pkg-has-shlibs-control-file-but-no-actual-shared-libs');
         }
     } else {
         # shared libraries included, thus shlibs control file has to exist
@@ -362,7 +384,7 @@ sub run {
                 for my $shlib (@shlibs) {
                     # skip it if it's not a public shared library
                     next unless $ldconfig_dirs->known(dirname($shlib));
-                    tag 'no-shlibs-control-file', $shlib
+                    $self->tag('no-shlibs-control-file', $shlib)
                       unless is_nss_plugin($shlib);
                 }
             }
@@ -381,8 +403,8 @@ sub run {
                 @words = split(/\s+/o,$_);
                 my $shlibs_string = $udeb.$words[0].' '.$words[1];
                 if ($shlibs_control{$shlibs_string}) {
-                    tag 'duplicate-entry-in-shlibs-control-file',
-                      $shlibs_string;
+                    $self->tag('duplicate-entry-in-shlibs-control-file',
+                        $shlibs_string);
                 } else {
                     $shlibs_control{$shlibs_string} = 1;
                     push(@shlibs_depends, join(' ', @words[2 .. $#words]))
@@ -399,13 +421,13 @@ sub run {
                     # skip it if it's not a public shared library
                     next unless $ldconfig_dirs->known(dirname($shlib));
                     # no!!
-                    tag 'shlib-missing-in-control-file', $shlib_name, 'for',
-                      $shlib
+                    $self->tag('shlib-missing-in-control-file',
+                        $shlib_name, 'for',$shlib)
                       unless is_nss_plugin($shlib);
                 }
             }
             for my $shlib_name (keys %shlibs_control) {
-                tag 'unused-shlib-entry-in-control-file', $shlib_name
+                $self->tag('unused-shlib-entry-in-control-file', $shlib_name)
                   unless $shlibs_control_used{$shlib_name};
             }
 
@@ -420,9 +442,10 @@ sub run {
             @shlibs_depends = uniq(@shlibs_depends);
             for my $depend (@shlibs_depends) {
                 unless ($provides->implies($depend)) {
-                    tag 'shlibs-declares-dependency-on-other-package', $depend;
+                    $self->tag('shlibs-declares-dependency-on-other-package',
+                        $depend);
                 }
-                tag 'shlibs-uses-obsolete-relation', $depend
+                $self->tag('shlibs-uses-obsolete-relation', $depend)
                   if $depend =~ m/\(\s*[><](?![<>=])\s*/;
             }
         }
@@ -434,7 +457,7 @@ sub run {
         # no shared libraries included in package, thus symbols
         # control file should not be present
         if ($symbolsf) {
-            tag 'pkg-has-symbols-control-file-but-no-shared-libs';
+            $self->tag('pkg-has-symbols-control-file-but-no-shared-libs');
         }
     } elsif (not $symbolsf) {
         if ($type ne 'udeb') {
@@ -445,7 +468,7 @@ sub run {
                 # appear in the symbol table
                 next if any { @{$_}[2] =~ m/^__objc_/ }
                 @{$objdump->{$shlib}{SYMBOLS}};
-                tag 'no-symbols-control-file', $shlib
+                $self->tag('no-symbols-control-file', $shlib)
                   unless is_nss_plugin($shlib);
             }
         }
@@ -459,6 +482,7 @@ sub run {
         my @symbols_depends;
         my $dep_templates = 0;
         my %meta_info_seen;
+        my $build_depends_seen = 0;
         my $warned = 0;
         my $symbol_count = 0;
 
@@ -475,7 +499,8 @@ sub run {
                 $soname = format_soname($soname);
 
                 if ($symbols_control{$soname}) {
-                    tag 'duplicate-entry-in-symbols-control-file', $soname;
+                    $self->tag('duplicate-entry-in-symbols-control-file',
+                        $soname);
                 } else {
                     $symbols_control{$soname} = 1;
                     $warned = 0;
@@ -488,7 +513,7 @@ sub run {
                             if (defined $dep_package) {
                                 push @symbols_depends, $dep_package . $dep;
                             } else {
-                                tag 'syntax-error-in-symbols-file', $.
+                                $self->tag('syntax-error-in-symbols-file', $.)
                                   unless $warned;
                                 $warned = 1;
                             }
@@ -498,13 +523,14 @@ sub run {
 
                 $dep_templates = 0;
                 $symbol_count = 0;
+                undef %meta_info_seen;
             } elsif (m/^\|\s+\S+\s*(?:\(\S+\s+\S+\)|#MINVER#)?/) {
                 # alternative dependency template
 
                 $warned = 0;
 
                 if (%meta_info_seen or not defined $soname) {
-                    tag 'syntax-error-in-symbols-file', $.;
+                    $self->tag('syntax-error-in-symbols-file', $.);
                     $warned = 1;
                 }
 
@@ -517,7 +543,7 @@ sub run {
                         if (defined $dep_package) {
                             push @symbols_depends, $dep_package . $dep;
                         } else {
-                            tag 'syntax-error-in-symbols-file', $.
+                            $self->tag('syntax-error-in-symbols-file', $.)
                               unless $warned;
                             $warned = 1;
                         }
@@ -528,16 +554,17 @@ sub run {
             } elsif (m/^\*\s(\S+):\s\S+/) {
                 # meta-information
 
-                tag 'unknown-meta-field-in-symbols-file', "$1, line $."
+                $self->tag('unknown-meta-field-in-symbols-file', "$1, line $.")
                   unless exists $symbols_meta_fields{$1};
-                tag 'syntax-error-in-symbols-file', $.
+                $self->tag('syntax-error-in-symbols-file', $.)
                   unless defined $soname and $symbol_count == 0;
 
                 $meta_info_seen{$1} = 1;
+                $build_depends_seen = 1 if $1 eq 'Build-Depends-Package';
             } elsif (m/^\s+(\S+)\s(\S+)(?:\s(\S+(?:\s\S+)?))?$/) {
                 # Symbol definition
 
-                tag 'syntax-error-in-symbols-file', $.
+                $self->tag('syntax-error-in-symbols-file', $.)
                   unless defined $soname;
 
                 $symbol_count++;
@@ -556,13 +583,13 @@ sub run {
 
                 if (length $dep_order) {
                     if ($dep_order !~ /^\d+$/ or $dep_order > $dep_templates) {
-                        tag 'invalid-template-id-in-symbols-file', $.;
+                        $self->tag('invalid-template-id-in-symbols-file', $.);
                     }
                 }
             } else {
                 # Unparseable line
 
-                tag 'syntax-error-in-symbols-file', $.;
+                $self->tag('syntax-error-in-symbols-file', $.);
             }
         }
         close($fd);
@@ -572,8 +599,9 @@ sub run {
             if ($full_version_count > 0) {
                 $others = " and $full_version_count others";
             }
-            tag 'symbols-file-contains-current-version-with-debian-revision',
-              "on symbol $full_version_sym$others";
+            $self->tag(
+                'symbols-file-contains-current-version-with-debian-revision',
+                "on symbol $full_version_sym$others");
         }
         if ($debian_revision_count) {
             $debian_revision_count--;
@@ -581,8 +609,10 @@ sub run {
             if ($debian_revision_count > 0) {
                 $others = " and $debian_revision_count others";
             }
-            tag 'symbols-file-contains-debian-revision',
-              "on symbol $debian_revision_sym$others";
+            $self->tag(
+                'symbols-file-contains-debian-revision',
+                "on symbol $debian_revision_sym$others"
+            );
         }
         for my $shlib (@shlibs, keys %unversioned_shlibs) {
             my $shlib_name = $SONAME{$shlib};
@@ -592,17 +622,18 @@ sub run {
             unless (exists $symbols_control{$shlib_name}) {
                 # skip it if it's not a public shared library
                 next unless $ldconfig_dirs->known(dirname($shlib));
-                tag 'shlib-missing-in-symbols-control-file', $shlib_name,
-                  'for', $shlib
+                $self->tag('shlib-missing-in-symbols-control-file',
+                    $shlib_name,'for', $shlib)
                   unless is_nss_plugin($shlib);
             }
         }
         for my $shlib_name (keys %symbols_control) {
-            tag 'unused-shlib-entry-in-symbols-control-file', $shlib_name
+            $self->tag('unused-shlib-entry-in-symbols-control-file',
+                $shlib_name)
               unless $symbols_control_used{$shlib_name};
         }
-        tag 'symbols-file-missing-build-depends-package-field'
-          unless exists $meta_info_seen{'Build-Depends-Package'};
+        $self->tag('symbols-file-missing-build-depends-package-field')
+          unless $build_depends_seen;
 
         # Check that all of the packages listed as dependencies in the symbols
         # file are satisfied by the current package or its Provides.
@@ -616,7 +647,8 @@ sub run {
             my $d = $depend;
             $d =~ s/ \#MINVER\#$//;
             unless ($provides->implies($d)) {
-                tag 'symbols-declares-dependency-on-other-package', $depend;
+                $self->tag('symbols-declares-dependency-on-other-package',
+                    $depend);
             }
         }
     }
@@ -627,40 +659,41 @@ sub run {
     if (keys %shlibs_control and keys %symbols_control) {
         for my $key (keys %symbols_control) {
             unless (exists $shlibs_control{$key} or $key !~ / /) {
-                tag 'symbols-declared-but-not-shlib', $key;
+                $self->tag('symbols-declared-but-not-shlib', $key);
             }
         }
     }
 
     # 6th step: check pre- and post- control files
-    if (my $preinst = $info->control_index_resolved_path('preinst')) {
+    if (my $preinst = $processable->control_index_resolved_path('preinst')) {
         if ($preinst->is_open_ok) {
             if ($preinst->file_contents =~ m/^[^\#]*\bldconfig\b/m) {
-                tag 'maintscript-calls-ldconfig', 'preinst'
-                  # Assume it is needed if glibc does it
-                  if $proc->pkg_src ne 'glibc';
+                $self->tag(
+                    'maintscript-calls-ldconfig', 'preinst'
+                      # Assume it is needed if glibc does it
+                ) if $processable->source ne 'glibc';
             }
         }
     }
 
     my $we_trigger_ldconfig = 0;
-    if (my $postinst = $info->control_index_resolved_path('postinst')) {
+    if (my $postinst = $processable->control_index_resolved_path('postinst')) {
         if ($postinst->is_open_ok) {
             # Decide if we call ldconfig
             if ($postinst->file_contents =~ m/^[^\#]*\bldconfig\b/m) {
                 if ($type eq 'udeb') {
-                    tag 'udeb-postinst-must-not-call-ldconfig';
+                    $self->tag('udeb-postinst-must-not-call-ldconfig');
                 } else {
                     # glibc (notably libc-bin) needs to call ldconfig in
                     # order to implement the "ldconfig" trigger.
-                    tag 'maintscript-calls-ldconfig', 'postinst'
-                      if $proc->pkg_src ne 'glibc';
+                    $self->tag('maintscript-calls-ldconfig', 'postinst')
+                      if $processable->source ne 'glibc';
                 }
             }
         }
     }
 
-    if (my $triggers = $info->control_index_resolved_path('triggers')) {
+    if (my $triggers = $processable->control_index_resolved_path('triggers')) {
         if ($triggers->is_open_ok) {
             # Determine if the package had an ldconfig trigger
             my $fd = $triggers->open;
@@ -677,43 +710,64 @@ sub run {
     }
 
     if ($type eq 'udeb') {
-        tag 'udeb-postinst-must-not-call-ldconfig'
+        $self->tag('udeb-postinst-must-not-call-ldconfig')
           if $we_trigger_ldconfig;
     } else {
-        tag 'package-has-unnecessary-activation-of-ldconfig-trigger'
+        $self->tag('package-has-unnecessary-activation-of-ldconfig-trigger')
           if $we_trigger_ldconfig and not $must_call_ldconfig;
-        tag 'package-must-activate-ldconfig-trigger', $must_call_ldconfig
+        $self->tag('package-must-activate-ldconfig-trigger',
+            $must_call_ldconfig)
           if not $we_trigger_ldconfig and $must_call_ldconfig;
     }
 
-    my $multiarch = $info->field('multi-arch', 'no');
+    my $multiarch = $processable->field('multi-arch', 'no');
     if ($multiarch eq 'foreign' and $must_call_ldconfig) {
-        tag 'shlib-in-multi-arch-foreign-package', $must_call_ldconfig;
+        $self->tag('shlib-in-multi-arch-foreign-package', $must_call_ldconfig);
     }
 
-    if (my $prerm = $info->control_index_resolved_path('prerm')) {
+    if (my $prerm = $processable->control_index_resolved_path('prerm')) {
         if ($prerm->is_open_ok) {
             if ($prerm->file_contents =~ m/^[^\#]*\bldconfig\b/m) {
-                tag 'maintscript-calls-ldconfig', 'prerm'
-                  # Assume it is needed if glibc does it
-                  if $proc->pkg_src ne 'glibc';
+                $self->tag(
+                    'maintscript-calls-ldconfig', 'prerm'
+                      # Assume it is needed if glibc does it
+                ) if $processable->source ne 'glibc';
             }
         }
     }
 
-    if (my $postrm = $info->control_index_resolved_path('postrm')) {
+    if (my $postrm = $processable->control_index_resolved_path('postrm')) {
         if ($postrm->is_open_ok) {
             my $contents = $postrm->file_contents;
 
             # Decide if we call ldconfig
             if ($contents =~ m/^[^\#]*\bldconfig\b/m) {
-                tag 'maintscript-calls-ldconfig', 'postrm'
-                  # Assume it is needed if glibc does it
-                  if $proc->pkg_src ne 'glibc';
+                $self->tag(
+                    'maintscript-calls-ldconfig', 'postrm'
+                      # Assume it is needed if glibc does it
+                ) if $processable->source ne 'glibc';
             }
         }
     }
 
+    foreach my $file ($processable->sorted_index) {
+        next unless $file =~ m,^usr/(lib(/[^/]+)?|share)/pkgconfig/[^/]+\.pc$,;
+        next unless $file->is_open_ok;
+        my $fd = $file->open;
+        while (<$fd>) {
+            next unless m,^Libs:,;
+            while (/[:\s]-l(\S+)/g) {
+                $self->tag('pkg-config-references-unknown-shared-library',
+                    $file, "-l$1", "(line $.)")
+                  unless $1 =~ m/\$\{.+\}/
+                  or exists($SONAMES{$1})
+                  or exists($STATIC_LIBS{$1})
+                  or $UNKNOWN_SHARED_LIBRARY_EXCEPTIONS->known($1);
+            }
+        }
+        close($fd);
+    }
+
     return;
 }
 
@@ -753,7 +807,7 @@ sub needs_ldconfig {
     $dirname .= "/$last" if $last;
     # yes! so postinst must call ldconfig
     return 1 if $ldconfig_dirs->known($dirname);
-    return;
+    return 0;
 }
 
 1;
